Backup/Restore and DR service
=============================

.. toctree::
   :maxdepth: 2

   get_started
   install
   verify
   next-steps

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial
<https://docs.openstack.org/install-guide/>`_.
